Improve this doc View Source

Specify custom behavior on mousemove event.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as attribute:

      <ANY
        ng-mousemove="">
      ...
      </ANY>

### Arguments

Param | Type | Details
--- | --- | ---
ngMousemove | expression | Expression to evaluate upon mousemove. (Event object is available as `$event`)

## Example

Edit in Plunker

    <button ng-mousemove="count = count + 1" ng-init="count=0">
      Increment (when mouse moves)
    </button>
    count: {{count}}